@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Result::Jolt;
 # ABSTRACT: Jolt result handler
-$Neo4j::Driver::Result::Jolt::VERSION = '0.41';
+$Neo4j::Driver::Result::Jolt::VERSION = '0.42';
 
 # This package is not part of the public Neo4j::Driver API.
 
@@ -291,13 +291,21 @@ sub _deep_bless {
 		return $path;
 	}
 	if ($sigil eq '@') {  # Spatial
-		# TODO
 		bless $data, $cypher_types->{point};
 		return $data;
 	}
 	if ($sigil eq 'T') {  # Temporal
-		# TODO
-		bless $data, $cypher_types->{temporal};
+		if ($cypher_types->{temporal} ne 'Neo4j::Driver::Type::Temporal') {
+			return bless $data, $cypher_types->{temporal};
+		}
+		if ($value =~ m/^-?P/) {
+			require Neo4j::Driver::Type::Duration;
+			bless $data, 'Neo4j::Driver::Type::Duration';
+		}
+		else {
+			require Neo4j::Driver::Type::DateTime;
+			bless $data, 'Neo4j::Driver::Type::DateTime';
+		}
 		return $data;
 	}
 	if ($sigil eq '#') {  # Bytes
