@@ -5,9 +5,41 @@ use utf8;
 
 package Neo4j::Driver::Type::Point;
 # ABSTRACT: Represents a Neo4j spatial point value
-$Neo4j::Driver::Type::Point::VERSION = '0.41';
+$Neo4j::Driver::Type::Point::VERSION = '0.42';
+
+use parent 'Neo4j::Types::Point';
+
+
+sub _parse {
+	my ($self) = @_;
+	
+	if ( ! exists $self->{'@'} ) {  # JSON format
+		$self->{srid} = $self->{crs}{srid};
+		return;
+	}
+	
+	my ($srid, $x, $y, $z) = $self->{'@'} =~ m/^SRID=([0-9]+);POINT(?: Z)? ?\(([-0-9.]+) ([-0-9.]+)(?: ([-0-9.]+))?\)$/;
+	
+	$self->{srid} = 0 + $srid;
+	my @coords = (0 + $x, 0 + $y);
+	push @coords, 0 + $z if defined $z;
+	$self->{coordinates} = \@coords;
+}
+
+
+sub srid {
+	my ($self) = @_;
+	exists $self->{srid} or $self->_parse;
+	return $self->{srid};
+}
+
+
+sub coordinates {
+	my ($self) = @_;
+	exists $self->{coordinates} or $self->_parse;
+	return @{$self->{coordinates}};
+}
 
-# may not be supported by Bolt
 
 1;
 
@@ -23,7 +55,7 @@ Neo4j::Driver::Type::Point - Represents a Neo4j spatial point value
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 DESCRIPTION
 
@@ -34,15 +66,6 @@ Spatial types are only supported in Neo4j version 3.4 and above.
 I<B<Note:> This module documentation will soon be replaced entirely
 by L<Neo4j::Driver::Types> and L<Neo4j::Types::Point>.>
 
-=head1 BUGS
-
-L<Neo4j::Driver::Type::Point> is not yet implemented.
-
-Spatial types may not work over a Bolt connection, because they
-are not yet supported by C<libneo4j-client>
-(L<#36|https://github.com/cleishm/libneo4j-client/issues/36>),
-which L<Neo4j::Bolt> depends on internally. Use HTTP instead.
-
 =head1 SEE ALSO
 
 =over
@@ -60,10 +83,7 @@ L<Point (Java)|https://neo4j.com/docs/api/java-driver/5.2/org.neo4j.driver/org/n
 
 =head1 AUTHOR
 
-Arne Johannessen <ajnn@cpan.org>
-
-If you contact me by email, please make sure you include the word
-"Perl" in your subject header to help beat the spam filters.
+Arne Johannessen (L<AJNN|https://arne.johannessen.de/>)
 
 =head1 COPYRIGHT AND LICENSE
 
