@@ -32,7 +32,7 @@ sub driver_maybe {
 	$driver->config(timeout => 2);  # 2 seconds timeout may speed up testing
 	$driver->config(cypher_params => v2);
 	
-	$bolt = $driver->{uri} && $driver->{uri}->scheme eq 'bolt';
+	$bolt = $driver->config('uri') && $driver->config('uri')->scheme eq 'bolt';
 	if ($ENV{TEST_NEO4J_NETMODULE}) {
 		eval "require $ENV{TEST_NEO4J_NETMODULE} unless $ENV{TEST_NEO4J_NETMODULE}->can('new'); 1" or die;
 		$driver->plugin(Neo4j_Test::NetModulePlugin->new($ENV{TEST_NEO4J_NETMODULE}));
@@ -67,9 +67,10 @@ sub driver {
 
 # returns a driver that is expected to fail (no connection)
 sub driver_no_connect {
-	# NXDOMAIN via DNS is slow; Port 14 is unassigned and should be closed
+	# Port 14 is unassigned and should be closed. The IP address is the
+	# multicast address that belongs to TEST-NET-1 and should fail.
 	driver_maybe;  # init $bolt
-	my $driver = Neo4j::Driver->new(($bolt ? 'bolt' : 'http') . '://localhost:14');
+	my $driver = Neo4j::Driver->new(($bolt ? 'bolt' : 'http') . '://234.192.0.2:14');
 	return $driver;
 }
 
@@ -81,7 +82,7 @@ sub driver_no_auth {
 		delete $driver->{plugins}->{handlers}->{http_adapter_factory};
 		$driver->plugin(Neo4j_Test::NetModulePlugin->new( Neo4j_Test::Sim->new({auth => 0}) ));
 	}
-	$driver->{auth} = { scheme => 'basic', principal => "no\tuser", credentials => "no\tpass" };
+	$driver->{config}->{auth} = { scheme => 'basic', principal => "no\tuser", credentials => "no\tpass" };
 	return $driver;
 }
 
@@ -98,14 +99,6 @@ sub transaction_unconnected {
 }
 
 
-# used for the ResultSummary/ServerInfo test
-sub server_address {
-	return 'localhost:7474' unless $ENV{TEST_NEO4J_SERVER};
-	return 'localhost:7687' if $ENV{TEST_NEO4J_SERVER} =~ m{^bolt:(?://(?:localhost\b)?)?}i;
-	return '' . (URI->new( $ENV{TEST_NEO4J_SERVER} )->host_port // '');
-}
-
-
 1;
 
 __END__
